﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class AtkSkillScript : MonoBehaviour
{
    public delegate void NotifyIA(Vector2 position);
    public static NotifyIA notify;

    private Animator stateMachine;
    private Rigidbody2D rb;
    private bool isMoving;
    private Vector2 skillDirection;

    [SerializeField] private KeyCode crossOver;
    [SerializeField] private KeyCode spin;
    [SerializeField] private KeyCode stepBack;
    [SerializeField] private float timeEffect;
    
    // Use this for initialization
    void Start()
    {
        rb = GetComponent<Rigidbody2D>();
        isMoving = false;
        OnEnable();
        skillDirection = new Vector2(0, -1);
    }

    // Update is called once per frame
    void Update()
    {
        if (Input.GetKeyDown(crossOver) && !isMoving)
        {
            stateMachine.Play("CrossOver");
            changeHand();
        }
        if (Input.GetKeyDown(spin) && !isMoving)
        {
            stateMachine.Play("Spin");
            StartCoroutine(notifyIA(rb.position, Vector2.right, skillDirection));
            rb.MovePosition(rb.position + Vector2.right + skillDirection);
        }
        if (Input.GetKeyDown(stepBack) && !isMoving)
        {
            stateMachine.Play("StepBack");
            StartCoroutine(notifyIA(rb.position, Vector2.left, skillDirection));
            rb.MovePosition(rb.position + Vector2.left + skillDirection);
        }
    }

    private void moving()
    {
        isMoving = true;
    }

    private void notMoving()
    {
        isMoving = false;
    }

    private void changeHand()
    {
        skillDirection *= -1;
    }

    private IEnumerator notifyIA(Vector2 position, Vector2 skill, Vector2 direction)
    {
        if (notify != null)
        {
            yield return new WaitForSeconds(timeEffect);
            notify(skill);
            yield return new WaitForSeconds(timeEffect);
            notify(direction);
        }
    }

    public void setStateMachine(Animator animator)
    {
        stateMachine = animator;
    }

    public void updateStateMachine(AnimatorOverrideController animator)
    {
        stateMachine.runtimeAnimatorController = animator;
    }

    private void OnEnable()
    {
        MovingBehavior.enterMoving = moving;
        MovingBehavior.exitMoving = notMoving;
    }

    private void OnDisable()
    {
        MovingBehavior.enterMoving -= moving;
        MovingBehavior.exitMoving -= notMoving;
    }
}
