﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class IAAtkScript : MonoBehaviour
{
    private Animator stateMachine;
    private Rigidbody2D rb;
    private bool isMoving;
    private bool isShooting;
    private Vector2 skillDirection;
    private Coroutine loop;

    [SerializeField] private GameObject ball;
    [SerializeField] private GameObject basket;
    [SerializeField] private Transform spawnPosition;
    [SerializeField] private float xForce;
    [SerializeField] private float minYForce;
    [SerializeField] private float maxYForce;
    [SerializeField] private float timeEffect;

    // Use this for initialization
    void Start()
    {
        isMoving = false;
        isShooting = false;
        OnEnable();
        skillDirection = new Vector2(0, -1);
    }
    //ternario exemplo Random.Range(0, 10) == 1 ? true : false

    private void Update()
    {
        
    }

    private void moving()
    {
        isMoving = true;
    }

    private void notMoving()
    {
        isMoving = false;
    }

    private void changeHand()
    {
        skillDirection *= -1;
    }

    private IEnumerator atkLoop()
    {
        while (true)
        {
            if (!isMoving && !isShooting)
            {
                yield return movement(Random.Range(0, 10));
            }
            yield return null;
        }
    }

    private IEnumerator movement(int choice)
    {
        switch (choice)
        {
            //W - Move
            case 0:
                stateMachine.Play("Movimento");
                rb.MovePosition(rb.position + Vector2.up);
                yield return new WaitForSeconds(timeEffect);
                break;
            //A - Move
            case 1:
                stateMachine.Play("Movimento");
                rb.MovePosition(rb.position + Vector2.left);
                yield return new WaitForSeconds(timeEffect);
                break;
            //S - Move
            case 2:
                stateMachine.Play("Movimento");
                rb.MovePosition(rb.position + Vector2.down);
                yield return new WaitForSeconds(timeEffect);
                break;
            //D - Move
            case 3:
                stateMachine.Play("Movimento");
                rb.MovePosition(rb.position + Vector2.right);
                yield return new WaitForSeconds(timeEffect);
                break;
            //Z - Spin
            case 4:
                stateMachine.Play("CrossOver");
                rb.MovePosition(rb.position + Vector2.left + skillDirection);
                yield return new WaitForSeconds(timeEffect);
                break;
            //X - CrossOver
            case 5:
                stateMachine.Play("Spin");
                changeHand();
                yield return new WaitForSeconds(timeEffect);
                break;
            //C - StepBack
            case 6:
                stateMachine.Play("StepBack");
                rb.MovePosition(rb.position + Vector2.right + skillDirection);
                yield return new WaitForSeconds(timeEffect);
                break;
            //Space - Shoot
            default:
                stateMachine.Play("Arremesso");
                break;
        }
    }

    private void shoot()
    {
        if (isActiveAndEnabled)
        {
            Vector3 norTar = (basket.transform.position - transform.position).normalized;
            GameObject clone = Instantiate(ball, spawnPosition.position, spawnPosition.rotation) as GameObject;
            Vector2 vector = new Vector2(norTar.x * xForce, Random.Range(minYForce, maxYForce) - transform.position.y);
            clone.GetComponent<Rigidbody2D>().AddForce(vector, ForceMode2D.Impulse);
        }
    }

    public void startLoop()
    {
        loop = StartCoroutine(atkLoop());
    }

    public void endLoop()
    {
        if (loop != null)
        {
            StopCoroutine(loop);
        }
    }

    public void updateStateMachine(AnimatorOverrideController animator)
    {
        stateMachine.runtimeAnimatorController = animator;
    }

    public void setStateMachine(Animator animator)
    {
        stateMachine = animator;
    }

    public void setRigidBody(Rigidbody2D rigidBody)
    {
        rb = rigidBody;
    }

    private void OnEnable()
    {
        MovingBehavior.enterMoving = moving;
        MovingBehavior.exitMoving = notMoving;
        ThrowingBehavior.exitThrowing = shoot;
    }

    private void OnDisable()
    {
        MovingBehavior.enterMoving -= moving;
        MovingBehavior.exitMoving -= notMoving;
        ThrowingBehavior.exitThrowing -= shoot;
    }
}
